@@ -13,7 +13,6 @@ import aiohttp
 import aiohttp.client_exceptions
 import certifi
 from tqdm import tqdm
-import yarl
 
 from .base_functions import *
 from .data_classes import *
@@ -31,14 +30,14 @@ def retry(f):
             try:
                 return await f(self, *args, **kwargs)
             except FailureException:
-                if i == self.attempts - 1:
+                if i >= self.attempts - 1:
                     raise
                 logger.debug('Retrying...')
-                time.sleep(4)
+                time.sleep(2)
     return wrapper
 
 
-async def throttle(self, url: yarl.URL) -> None:
+async def throttle(self, url: URL) -> None:
     host = url.host
     if host is None:
         return
@@ -66,13 +65,18 @@ async def throttle(self, url: yarl.URL) -> None:
 
 
 class Downloader:
-    def __init__(self, album_obj: AlbumItem, morsels, folder: Path, title: str, attempts: int, max_workers: int):
+    def __init__(self, album_obj: AlbumItem, morsels, folder: Path, title: str, attempts: int, max_workers: int,
+                 exclude_videos: bool, exclude_images: bool, exclude_audio: bool, exclude_other: bool):
         self.album_obj = album_obj
         self.morsels = morsels
         self.folder = folder
         self.title = title
         self.attempts = attempts
         self.max_workers = max_workers
+        self.exclude_videos = exclude_videos
+        self.exclude_images = exclude_images
+        self.exclude_audio = exclude_audio
+        self.exclude_other = exclude_other
         self._semaphore = asyncio.Semaphore(max_workers)
         self.delay = {'media-files.bunkr.is': 2}
         self.throttle_times = {}
@@ -82,20 +86,20 @@ class Downloader:
     @retry
     async def download_file(
             self,
-            url: str,
-            referral: str,
+            url: URL,
+            referral: URL,
             filename: str,
             session: aiohttp.ClientSession,
             show_progress: bool = True
     ) -> None:
         """Download the content of given URL"""
-        headers = {'Referer': referral, 'user-agent': user_agent}
+        headers = {'Referer': str(referral), 'user-agent': user_agent}
         ssl_context = ssl.create_default_context(cafile=certifi.where())
 
         try:
             async with self._semaphore:
-                if yarl.URL(url).host in self.delay:
-                    await throttle(self, yarl.URL(url))
+                if url.host in self.delay:
+                    await throttle(self, url)
 
                 ext = '.'+filename.split('.')[-1]
                 if not (ext in FILE_FORMATS['Images'] or ext in FILE_FORMATS['Videos'] or ext in FILE_FORMATS['Audio'] or ext in FILE_FORMATS['Other']):
@@ -106,6 +110,25 @@ class Downloader:
                     if (self.folder / self.title / filename).exists():
                         return
 
+                # Skip based on CLI arg.
+                ext = '.' + filename.split('.')[-1]
+                if self.exclude_videos:
+                    if ext in FILE_FORMATS['Videos']:
+                        logging.debug("Skipping " + filename)
+                        return
+                if self.exclude_images:
+                    if ext in FILE_FORMATS['Images']:
+                        logging.debug("Skipping " + filename)
+                        return
+                if self.exclude_audio:
+                    if ext in FILE_FORMATS['Audio']:
+                        logging.debug("Skipping " + filename)
+                        return
+                if self.exclude_other:
+                    if ext in FILE_FORMATS['Other']:
+                        logging.debug("Skipping " + filename)
+                        return
+
                 resume_point = 0
                 complete_file = (self.folder / self.title / filename)
                 temp_file = complete_file.with_suffix(complete_file.suffix + '.part')
@@ -156,9 +179,9 @@ class Downloader:
         """Download the content of given URL and store it in a file."""
         url, referral = url_tuple
 
-        filename = url.split("/")[-1]
+        filename = url.name
         filename = sanitize(filename)
-        if "?v=" in url:
+        if "v=" in filename:
             filename = filename.split('v=')[0]
         if len(filename) > MAX_FILENAME_LENGTH:
             fileext = filename.split('.')[-1]
@@ -167,14 +190,14 @@ class Downloader:
         if (self.folder / self.title / filename).exists():
             logger.debug(str(self.folder / self.title / filename) + " Already Exists")
         else:
-            logger.debug("Working on " + url)
+            logger.debug("Working on " + str(url))
             try:
                 await self.download_file(url, referral=referral, filename=filename,
                                          session=session, show_progress=show_progress)
             except Exception:
                 logger.debug(traceback.format_exc())
                 log(f"\nSkipping {filename}: likely exceeded download attempts (or ran into an error)\nRe-run program "
-                    f"after exit to continue download.", Fore.WHITE)
+                    f"after exit to continue download.\n", Fore.WHITE)
 
     async def download_all(
             self,
@@ -218,7 +241,8 @@ def simple_cookies(cookies):
     return morsels
 
 
-def get_downloaders(Cascade: CascadeItem, folder: Path, attempts: int, threads: int) -> list[Downloader]:
+def get_downloaders(Cascade: CascadeItem, folder: Path, attempts: int, threads: int, exclude_videos: bool,
+                    exclude_images: bool, exclude_audio: bool, exclude_other: bool) -> List[Downloader]:
     """Get a list of downloaders for each supported type of URLs.
     We shouldn't just assume that each URL will have the same netloc as
     the first one, so we need to classify them one by one, sort them to
@@ -235,6 +259,8 @@ def get_downloaders(Cascade: CascadeItem, folder: Path, attempts: int, threads:
             max_workers = 2 if (max_workers > 2) else max_workers
         for title, album_obj in domain_obj.albums.items():
             downloader = Downloader(album_obj, morsels=morsels, title=title, folder=folder,
-                                    attempts=attempts, max_workers=max_workers)
+                                    attempts=attempts, max_workers=max_workers, exclude_videos=exclude_videos,
+                                    exclude_images=exclude_images, exclude_audio=exclude_audio,
+                                    exclude_other=exclude_other)
             downloaders.append(downloader)
     return downloaders
